# ProgLearn

[![Build Status](https://travis-ci.org/neurodata/ProgLearn.svg?branch=main)](https://travis-ci.org/neurodata/ProgLearn)
[![Codecov](https://codecov.io/gh/neurodata/ProgLearn/branches/main/graph/badge.svg)](https://codecov.io/gh/neurodata/ProgLearn)
[![PyPI version](https://img.shields.io/pypi/v/proglearn.svg)](https://pypi.org/project/proglearn/)
[![arXiv](https://img.shields.io/badge/arXiv-2004.12908-red.svg?style=flat)](https://arxiv.org/abs/2004.12908)
[![License](https://img.shields.io/badge/License-MIT-blue)](https://opensource.org/licenses/MIT)
[![Netlify Status](https://img.shields.io/netlify/97f86f49-81ed-4292-a100-f7031b54ecc7)](https://app.netlify.com/sites/neuro-data-proglearn/deploys)
[![Downloads](https://img.shields.io/pypi/dm/proglearn.svg)](https://pypi.org/project/proglearn/#files)


`ProgLearn` (**Prog**ressive **Learn**ing) is a package for exploring and using progressive learning algorithms developed by the [neurodata group](https://neurodata.io).

- **Installation Guide:** [http://proglearn.neurodata.io/install.html](http://proglearn.neurodata.io/install.html)
- **Documentation:** [http://proglearn.neurodata.io](http://proglearn.neurodata.io)
- **Tutorials:** [http://proglearn.neurodata.io/tutorials.html](http://proglearn.neurodata.io/tutorials.html)
- **Source Code:** [http://proglearn.neurodata.io/reference/index.html](http://proglearn.neurodata.io/reference/index.html)
- **Issues:** [https://github.com/neurodata/proglearn/issues](https://github.com/neurodata/proglearn/issues)
- **Contribution Guide:** [http://proglearn.neurodata.io/contributing.html](http://proglearn.neurodata.io/contributing.html)

Some system/package requirements:
- **Python**: 3.6+
- **OS**: All major platforms (Linux, macOS, Windows)
- **Dependencies**: keras, scikit-learn, scipy, numpy, joblib
